# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/webrequest/v1/webrequest.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEgithub.com/metaprov/modelaapi/services/webrequest/v1/webrequest.proto\x12\x34github.com.metaprov.modelaapi.services.webrequest.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/data/v1alpha1/generated.proto\"\xd2\x01\n\x16ListWebRequestsRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12h\n\x06labels\x18\x03 \x03(\x0b\x32X.github.com.metaprov.modelaapi.services.webrequest.v1.ListWebRequestsRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8d\x01\n\x17ListWebRequestsResponse\x12Y\n\x0bwebrequests\x18\x01 \x01(\x0b\x32\x44.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.WebRequestList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x1a\n\x18\x43reateWebRequestResponse\"o\n\x17\x43reateWebRequestRequest\x12T\n\nwebrequest\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.WebRequest\"\x9f\x01\n\x17UpdateWebRequestRequest\x12T\n\nwebrequest\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.WebRequest\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\x1a\n\x18UpdateWebRequestResponse\"7\n\x14GetWebRequestRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"{\n\x15GetWebRequestResponse\x12T\n\nwebrequest\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.WebRequest\x12\x0c\n\x04yaml\x18\x02 \x01(\t\":\n\x17\x44\x65leteWebRequestRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x1a\n\x18\x44\x65leteWebRequestResponse\"l\n\x14RunWebRequestRequest\x12T\n\nwebrequest\x18\x01 \x01(\x0b\x32@.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.WebRequest\"\x17\n\x15RunWebRequestResponse2\xfe\n\n\x11WebRequestService\x12\xd3\x01\n\x0fListWebRequests\x12L.github.com.metaprov.modelaapi.services.webrequest.v1.ListWebRequestsRequest\x1aM.github.com.metaprov.modelaapi.services.webrequest.v1.ListWebRequestsResponse\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/v1/webrequests/{namespace}\x12\xcd\x01\n\x10\x43reateWebRequest\x12M.github.com.metaprov.modelaapi.services.webrequest.v1.CreateWebRequestRequest\x1aN.github.com.metaprov.modelaapi.services.webrequest.v1.CreateWebRequestResponse\"\x1a\x82\xd3\xe4\x93\x02\x14\"\x0f/v1/webrequests:\x01*\x12\xd4\x01\n\rGetWebRequest\x12J.github.com.metaprov.modelaapi.services.webrequest.v1.GetWebRequestRequest\x1aK.github.com.metaprov.modelaapi.services.webrequest.v1.GetWebRequestResponse\"*\x82\xd3\xe4\x93\x02$\x12\"/v1/webrequests/{namespace}/{name}\x12\x88\x02\n\x10UpdateWebRequest\x12M.github.com.metaprov.modelaapi.services.webrequest.v1.UpdateWebRequestRequest\x1aN.github.com.metaprov.modelaapi.services.webrequest.v1.UpdateWebRequestResponse\"U\x82\xd3\xe4\x93\x02O\x1aJ/v1/webrequests/{webrequest.metadata.namespace}/{webrequest.metadata.name}:\x01*\x12\xdd\x01\n\x10\x44\x65leteWebRequest\x12M.github.com.metaprov.modelaapi.services.webrequest.v1.DeleteWebRequestRequest\x1aN.github.com.metaprov.modelaapi.services.webrequest.v1.DeleteWebRequestResponse\"*\x82\xd3\xe4\x93\x02$*\"/v1/webrequests/{namespace}/{name}\x12\x80\x02\n\rRunWebRequest\x12J.github.com.metaprov.modelaapi.services.webrequest.v1.RunWebRequestRequest\x1aK.github.com.metaprov.modelaapi.services.webrequest.v1.RunWebRequestResponse\"V\x82\xd3\xe4\x93\x02P\"N/v1/webrequests/{webrequest.metadata.namespace}/{webrequest.metadata.name}:runB6Z4github.com/metaprov/modelaapi/services/webrequest/v1b\x06proto3')



_LISTWEBREQUESTSREQUEST = DESCRIPTOR.message_types_by_name['ListWebRequestsRequest']
_LISTWEBREQUESTSREQUEST_LABELSENTRY = _LISTWEBREQUESTSREQUEST.nested_types_by_name['LabelsEntry']
_LISTWEBREQUESTSRESPONSE = DESCRIPTOR.message_types_by_name['ListWebRequestsResponse']
_CREATEWEBREQUESTRESPONSE = DESCRIPTOR.message_types_by_name['CreateWebRequestResponse']
_CREATEWEBREQUESTREQUEST = DESCRIPTOR.message_types_by_name['CreateWebRequestRequest']
_UPDATEWEBREQUESTREQUEST = DESCRIPTOR.message_types_by_name['UpdateWebRequestRequest']
_UPDATEWEBREQUESTRESPONSE = DESCRIPTOR.message_types_by_name['UpdateWebRequestResponse']
_GETWEBREQUESTREQUEST = DESCRIPTOR.message_types_by_name['GetWebRequestRequest']
_GETWEBREQUESTRESPONSE = DESCRIPTOR.message_types_by_name['GetWebRequestResponse']
_DELETEWEBREQUESTREQUEST = DESCRIPTOR.message_types_by_name['DeleteWebRequestRequest']
_DELETEWEBREQUESTRESPONSE = DESCRIPTOR.message_types_by_name['DeleteWebRequestResponse']
_RUNWEBREQUESTREQUEST = DESCRIPTOR.message_types_by_name['RunWebRequestRequest']
_RUNWEBREQUESTRESPONSE = DESCRIPTOR.message_types_by_name['RunWebRequestResponse']
ListWebRequestsRequest = _reflection.GeneratedProtocolMessageType('ListWebRequestsRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTWEBREQUESTSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.webrequest.v1.webrequest_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequest.v1.ListWebRequestsRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTWEBREQUESTSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.webrequest.v1.webrequest_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequest.v1.ListWebRequestsRequest)
  })
_sym_db.RegisterMessage(ListWebRequestsRequest)
_sym_db.RegisterMessage(ListWebRequestsRequest.LabelsEntry)

ListWebRequestsResponse = _reflection.GeneratedProtocolMessageType('ListWebRequestsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTWEBREQUESTSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.webrequest.v1.webrequest_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequest.v1.ListWebRequestsResponse)
  })
_sym_db.RegisterMessage(ListWebRequestsResponse)

CreateWebRequestResponse = _reflection.GeneratedProtocolMessageType('CreateWebRequestResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEWEBREQUESTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.webrequest.v1.webrequest_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequest.v1.CreateWebRequestResponse)
  })
_sym_db.RegisterMessage(CreateWebRequestResponse)

CreateWebRequestRequest = _reflection.GeneratedProtocolMessageType('CreateWebRequestRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEWEBREQUESTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.webrequest.v1.webrequest_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequest.v1.CreateWebRequestRequest)
  })
_sym_db.RegisterMessage(CreateWebRequestRequest)

UpdateWebRequestRequest = _reflection.GeneratedProtocolMessageType('UpdateWebRequestRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEWEBREQUESTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.webrequest.v1.webrequest_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequest.v1.UpdateWebRequestRequest)
  })
_sym_db.RegisterMessage(UpdateWebRequestRequest)

UpdateWebRequestResponse = _reflection.GeneratedProtocolMessageType('UpdateWebRequestResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEWEBREQUESTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.webrequest.v1.webrequest_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequest.v1.UpdateWebRequestResponse)
  })
_sym_db.RegisterMessage(UpdateWebRequestResponse)

GetWebRequestRequest = _reflection.GeneratedProtocolMessageType('GetWebRequestRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETWEBREQUESTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.webrequest.v1.webrequest_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequest.v1.GetWebRequestRequest)
  })
_sym_db.RegisterMessage(GetWebRequestRequest)

GetWebRequestResponse = _reflection.GeneratedProtocolMessageType('GetWebRequestResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETWEBREQUESTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.webrequest.v1.webrequest_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequest.v1.GetWebRequestResponse)
  })
_sym_db.RegisterMessage(GetWebRequestResponse)

DeleteWebRequestRequest = _reflection.GeneratedProtocolMessageType('DeleteWebRequestRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEWEBREQUESTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.webrequest.v1.webrequest_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequest.v1.DeleteWebRequestRequest)
  })
_sym_db.RegisterMessage(DeleteWebRequestRequest)

DeleteWebRequestResponse = _reflection.GeneratedProtocolMessageType('DeleteWebRequestResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEWEBREQUESTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.webrequest.v1.webrequest_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequest.v1.DeleteWebRequestResponse)
  })
_sym_db.RegisterMessage(DeleteWebRequestResponse)

RunWebRequestRequest = _reflection.GeneratedProtocolMessageType('RunWebRequestRequest', (_message.Message,), {
  'DESCRIPTOR' : _RUNWEBREQUESTREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.webrequest.v1.webrequest_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequest.v1.RunWebRequestRequest)
  })
_sym_db.RegisterMessage(RunWebRequestRequest)

RunWebRequestResponse = _reflection.GeneratedProtocolMessageType('RunWebRequestResponse', (_message.Message,), {
  'DESCRIPTOR' : _RUNWEBREQUESTRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.webrequest.v1.webrequest_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.webrequest.v1.RunWebRequestResponse)
  })
_sym_db.RegisterMessage(RunWebRequestResponse)

_WEBREQUESTSERVICE = DESCRIPTOR.services_by_name['WebRequestService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z4github.com/metaprov/modelaapi/services/webrequest/v1'
  _LISTWEBREQUESTSREQUEST_LABELSENTRY._options = None
  _LISTWEBREQUESTSREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _WEBREQUESTSERVICE.methods_by_name['ListWebRequests']._options = None
  _WEBREQUESTSERVICE.methods_by_name['ListWebRequests']._serialized_options = b'\202\323\344\223\002\035\022\033/v1/webrequests/{namespace}'
  _WEBREQUESTSERVICE.methods_by_name['CreateWebRequest']._options = None
  _WEBREQUESTSERVICE.methods_by_name['CreateWebRequest']._serialized_options = b'\202\323\344\223\002\024\"\017/v1/webrequests:\001*'
  _WEBREQUESTSERVICE.methods_by_name['GetWebRequest']._options = None
  _WEBREQUESTSERVICE.methods_by_name['GetWebRequest']._serialized_options = b'\202\323\344\223\002$\022\"/v1/webrequests/{namespace}/{name}'
  _WEBREQUESTSERVICE.methods_by_name['UpdateWebRequest']._options = None
  _WEBREQUESTSERVICE.methods_by_name['UpdateWebRequest']._serialized_options = b'\202\323\344\223\002O\032J/v1/webrequests/{webrequest.metadata.namespace}/{webrequest.metadata.name}:\001*'
  _WEBREQUESTSERVICE.methods_by_name['DeleteWebRequest']._options = None
  _WEBREQUESTSERVICE.methods_by_name['DeleteWebRequest']._serialized_options = b'\202\323\344\223\002$*\"/v1/webrequests/{namespace}/{name}'
  _WEBREQUESTSERVICE.methods_by_name['RunWebRequest']._options = None
  _WEBREQUESTSERVICE.methods_by_name['RunWebRequest']._serialized_options = b'\202\323\344\223\002P\"N/v1/webrequests/{webrequest.metadata.namespace}/{webrequest.metadata.name}:run'
  _LISTWEBREQUESTSREQUEST._serialized_start=262
  _LISTWEBREQUESTSREQUEST._serialized_end=472
  _LISTWEBREQUESTSREQUEST_LABELSENTRY._serialized_start=427
  _LISTWEBREQUESTSREQUEST_LABELSENTRY._serialized_end=472
  _LISTWEBREQUESTSRESPONSE._serialized_start=475
  _LISTWEBREQUESTSRESPONSE._serialized_end=616
  _CREATEWEBREQUESTRESPONSE._serialized_start=618
  _CREATEWEBREQUESTRESPONSE._serialized_end=644
  _CREATEWEBREQUESTREQUEST._serialized_start=646
  _CREATEWEBREQUESTREQUEST._serialized_end=757
  _UPDATEWEBREQUESTREQUEST._serialized_start=760
  _UPDATEWEBREQUESTREQUEST._serialized_end=919
  _UPDATEWEBREQUESTRESPONSE._serialized_start=921
  _UPDATEWEBREQUESTRESPONSE._serialized_end=947
  _GETWEBREQUESTREQUEST._serialized_start=949
  _GETWEBREQUESTREQUEST._serialized_end=1004
  _GETWEBREQUESTRESPONSE._serialized_start=1006
  _GETWEBREQUESTRESPONSE._serialized_end=1129
  _DELETEWEBREQUESTREQUEST._serialized_start=1131
  _DELETEWEBREQUESTREQUEST._serialized_end=1189
  _DELETEWEBREQUESTRESPONSE._serialized_start=1191
  _DELETEWEBREQUESTRESPONSE._serialized_end=1217
  _RUNWEBREQUESTREQUEST._serialized_start=1219
  _RUNWEBREQUESTREQUEST._serialized_end=1327
  _RUNWEBREQUESTRESPONSE._serialized_start=1329
  _RUNWEBREQUESTRESPONSE._serialized_end=1352
  _WEBREQUESTSERVICE._serialized_start=1355
  _WEBREQUESTSERVICE._serialized_end=2761
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from github.com.metaprov.modelaapi.services.apitoken.v1 import apitoken_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_apitoken_dot_v1_dot_apitoken__pb2


class ApiTokenServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListApiTokens = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.apitoken.v1.ApiTokenService/ListApiTokens',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_apitoken_dot_v1_dot_apitoken__pb2.ListApiTokensRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_apitoken_dot_v1_dot_apitoken__pb2.ListApiTokensResponse.FromString,
                )
        self.CreateApiToken = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.apitoken.v1.ApiTokenService/CreateApiToken',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_apitoken_dot_v1_dot_apitoken__pb2.CreateApiTokenRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_apitoken_dot_v1_dot_apitoken__pb2.CreateApiTokenResponse.FromString,
                )
        self.GetApiToken = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.apitoken.v1.ApiTokenService/GetApiToken',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_apitoken_dot_v1_dot_apitoken__pb2.GetApiTokenRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_apitoken_dot_v1_dot_apitoken__pb2.GetApiTokenResponse.FromString,
                )
        self.UpdateApiToken = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.apitoken.v1.ApiTokenService/UpdateApiToken',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_apitoken_dot_v1_dot_apitoken__pb2.UpdateApiTokenRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_apitoken_dot_v1_dot_apitoken__pb2.UpdateApiTokenResponse.FromString,
                )
        self.DeleteApiToken = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.apitoken.v1.ApiTokenService/DeleteApiToken',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_apitoken_dot_v1_dot_apitoken__pb2.DeleteApiTokenRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_apitoken_dot_v1_dot_apitoken__pb2.DeleteApiTokenResponse.FromString,
                )


class ApiTokenServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListApiTokens(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateApiToken(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetApiToken(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateApiToken(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteApiToken(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ApiTokenServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListApiTokens': grpc.unary_unary_rpc_method_handler(
                    servicer.ListApiTokens,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_apitoken_dot_v1_dot_apitoken__pb2.ListApiTokensRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_apitoken_dot_v1_dot_apitoken__pb2.ListApiTokensResponse.SerializeToString,
            ),
            'CreateApiToken': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateApiToken,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_apitoken_dot_v1_dot_apitoken__pb2.CreateApiTokenRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_apitoken_dot_v1_dot_apitoken__pb2.CreateApiTokenResponse.SerializeToString,
            ),
            'GetApiToken': grpc.unary_unary_rpc_method_handler(
                    servicer.GetApiToken,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_apitoken_dot_v1_dot_apitoken__pb2.GetApiTokenRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_apitoken_dot_v1_dot_apitoken__pb2.GetApiTokenResponse.SerializeToString,
            ),
            'UpdateApiToken': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateApiToken,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_apitoken_dot_v1_dot_apitoken__pb2.UpdateApiTokenRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_apitoken_dot_v1_dot_apitoken__pb2.UpdateApiTokenResponse.SerializeToString,
            ),
            'DeleteApiToken': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteApiToken,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_apitoken_dot_v1_dot_apitoken__pb2.DeleteApiTokenRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_apitoken_dot_v1_dot_apitoken__pb2.DeleteApiTokenResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'github.com.metaprov.modelaapi.services.apitoken.v1.ApiTokenService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ApiTokenService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListApiTokens(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.apitoken.v1.ApiTokenService/ListApiTokens',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_apitoken_dot_v1_dot_apitoken__pb2.ListApiTokensRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_apitoken_dot_v1_dot_apitoken__pb2.ListApiTokensResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateApiToken(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.apitoken.v1.ApiTokenService/CreateApiToken',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_apitoken_dot_v1_dot_apitoken__pb2.CreateApiTokenRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_apitoken_dot_v1_dot_apitoken__pb2.CreateApiTokenResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetApiToken(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.apitoken.v1.ApiTokenService/GetApiToken',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_apitoken_dot_v1_dot_apitoken__pb2.GetApiTokenRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_apitoken_dot_v1_dot_apitoken__pb2.GetApiTokenResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateApiToken(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.apitoken.v1.ApiTokenService/UpdateApiToken',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_apitoken_dot_v1_dot_apitoken__pb2.UpdateApiTokenRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_apitoken_dot_v1_dot_apitoken__pb2.UpdateApiTokenResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteApiToken(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.apitoken.v1.ApiTokenService/DeleteApiToken',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_apitoken_dot_v1_dot_apitoken__pb2.DeleteApiTokenRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_apitoken_dot_v1_dot_apitoken__pb2.DeleteApiTokenResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/offlinefeaturestored/v1/offlinefeaturestored.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_data_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nYgithub.com/metaprov/modelaapi/services/offlinefeaturestored/v1/offlinefeaturestored.proto\x12>github.com.metaprov.modelaapi.services.offlinefeaturestored.v1\x1a\x45github.com/metaprov/modelaapi/pkg/apis/infra/v1alpha1/generated.proto\x1a\x44github.com/metaprov/modelaapi/pkg/apis/data/v1alpha1/generated.proto\"\xde\x02\n\x14\x43reateFeatureRequest\x12N\n\x07\x66\x65\x61ture\x18\x01 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Feature\x12U\n\nconnection\x18\x02 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12p\n\x06secret\x18\x03 \x03(\x0b\x32`.github.com.metaprov.modelaapi.services.offlinefeaturestored.v1.CreateFeatureRequest.SecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"\x17\n\x15\x43reateFeatureResponse\"0\n\x14\x44\x65leteFeatureRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\n\n\x02ns\x18\x02 \x01(\t\"\x17\n\x15\x44\x65leteFeatureResponse\"\xde\x02\n\x14UpdateFeatureRequest\x12N\n\x07\x66\x65\x61ture\x18\x01 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Feature\x12U\n\nconnection\x18\x02 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.Connection\x12p\n\x06secret\x18\x03 \x03(\x0b\x32`.github.com.metaprov.modelaapi.services.offlinefeaturestored.v1.UpdateFeatureRequest.SecretEntry\x1a-\n\x0bSecretEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\"\x17\n\x15UpdateFeatureResponse\"!\n\x13ListFeaturesRequest\x12\n\n\x02ns\x18\x01 \x01(\t\"k\n\x14ListFeaturesResponse\x12S\n\x08\x66\x65\x61tures\x18\x03 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeatureList\"-\n\x11GetFeatureRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\n\n\x02ns\x18\x02 \x01(\t\"d\n\x12GetFeatureResponse\x12N\n\x07\x66\x65\x61ture\x18\x01 \x01(\x0b\x32=.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.Feature\"\x8f\x01\n\x1eGenerateTrainingDatasetRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\n\n\x02ns\x18\x02 \x01(\t\x12S\n\x08\x66\x65\x61tures\x18\x03 \x01(\x0b\x32\x41.github.com.metaprov.modelaapi.pkg.apis.data.v1alpha1.FeatureList\"!\n\x1fGenerateTrainingDatasetResponse2\xb4\t\n\x1aOfflineFeatureStoreService\x12\xbe\x01\n\rCreateFeature\x12T.github.com.metaprov.modelaapi.services.offlinefeaturestored.v1.CreateFeatureRequest\x1aU.github.com.metaprov.modelaapi.services.offlinefeaturestored.v1.CreateFeatureResponse\"\x00\x12\xbe\x01\n\rDeleteFeature\x12T.github.com.metaprov.modelaapi.services.offlinefeaturestored.v1.DeleteFeatureRequest\x1aU.github.com.metaprov.modelaapi.services.offlinefeaturestored.v1.DeleteFeatureResponse\"\x00\x12\xbe\x01\n\rUpdateFeature\x12T.github.com.metaprov.modelaapi.services.offlinefeaturestored.v1.UpdateFeatureRequest\x1aU.github.com.metaprov.modelaapi.services.offlinefeaturestored.v1.UpdateFeatureResponse\"\x00\x12\xbb\x01\n\x0cListFeatures\x12S.github.com.metaprov.modelaapi.services.offlinefeaturestored.v1.ListFeaturesRequest\x1aT.github.com.metaprov.modelaapi.services.offlinefeaturestored.v1.ListFeaturesResponse\"\x00\x12\xb5\x01\n\nGetFeature\x12Q.github.com.metaprov.modelaapi.services.offlinefeaturestored.v1.GetFeatureRequest\x1aR.github.com.metaprov.modelaapi.services.offlinefeaturestored.v1.GetFeatureResponse\"\x00\x12\xdc\x01\n\x17GenerateTrainingDataset\x12^.github.com.metaprov.modelaapi.services.offlinefeaturestored.v1.GenerateTrainingDatasetRequest\x1a_.github.com.metaprov.modelaapi.services.offlinefeaturestored.v1.GenerateTrainingDatasetResponse\"\x00\x42@Z>github.com/metaprov/modelaapi/services/offlinefeaturestored/v1b\x06proto3')



_CREATEFEATUREREQUEST = DESCRIPTOR.message_types_by_name['CreateFeatureRequest']
_CREATEFEATUREREQUEST_SECRETENTRY = _CREATEFEATUREREQUEST.nested_types_by_name['SecretEntry']
_CREATEFEATURERESPONSE = DESCRIPTOR.message_types_by_name['CreateFeatureResponse']
_DELETEFEATUREREQUEST = DESCRIPTOR.message_types_by_name['DeleteFeatureRequest']
_DELETEFEATURERESPONSE = DESCRIPTOR.message_types_by_name['DeleteFeatureResponse']
_UPDATEFEATUREREQUEST = DESCRIPTOR.message_types_by_name['UpdateFeatureRequest']
_UPDATEFEATUREREQUEST_SECRETENTRY = _UPDATEFEATUREREQUEST.nested_types_by_name['SecretEntry']
_UPDATEFEATURERESPONSE = DESCRIPTOR.message_types_by_name['UpdateFeatureResponse']
_LISTFEATURESREQUEST = DESCRIPTOR.message_types_by_name['ListFeaturesRequest']
_LISTFEATURESRESPONSE = DESCRIPTOR.message_types_by_name['ListFeaturesResponse']
_GETFEATUREREQUEST = DESCRIPTOR.message_types_by_name['GetFeatureRequest']
_GETFEATURERESPONSE = DESCRIPTOR.message_types_by_name['GetFeatureResponse']
_GENERATETRAININGDATASETREQUEST = DESCRIPTOR.message_types_by_name['GenerateTrainingDatasetRequest']
_GENERATETRAININGDATASETRESPONSE = DESCRIPTOR.message_types_by_name['GenerateTrainingDatasetResponse']
CreateFeatureRequest = _reflection.GeneratedProtocolMessageType('CreateFeatureRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _CREATEFEATUREREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.offlinefeaturestored.v1.offlinefeaturestored_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.offlinefeaturestored.v1.CreateFeatureRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _CREATEFEATUREREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.offlinefeaturestored.v1.offlinefeaturestored_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.offlinefeaturestored.v1.CreateFeatureRequest)
  })
_sym_db.RegisterMessage(CreateFeatureRequest)
_sym_db.RegisterMessage(CreateFeatureRequest.SecretEntry)

CreateFeatureResponse = _reflection.GeneratedProtocolMessageType('CreateFeatureResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEFEATURERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.offlinefeaturestored.v1.offlinefeaturestored_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.offlinefeaturestored.v1.CreateFeatureResponse)
  })
_sym_db.RegisterMessage(CreateFeatureResponse)

DeleteFeatureRequest = _reflection.GeneratedProtocolMessageType('DeleteFeatureRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEFEATUREREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.offlinefeaturestored.v1.offlinefeaturestored_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.offlinefeaturestored.v1.DeleteFeatureRequest)
  })
_sym_db.RegisterMessage(DeleteFeatureRequest)

DeleteFeatureResponse = _reflection.GeneratedProtocolMessageType('DeleteFeatureResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEFEATURERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.offlinefeaturestored.v1.offlinefeaturestored_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.offlinefeaturestored.v1.DeleteFeatureResponse)
  })
_sym_db.RegisterMessage(DeleteFeatureResponse)

UpdateFeatureRequest = _reflection.GeneratedProtocolMessageType('UpdateFeatureRequest', (_message.Message,), {

  'SecretEntry' : _reflection.GeneratedProtocolMessageType('SecretEntry', (_message.Message,), {
    'DESCRIPTOR' : _UPDATEFEATUREREQUEST_SECRETENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.offlinefeaturestored.v1.offlinefeaturestored_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.offlinefeaturestored.v1.UpdateFeatureRequest.SecretEntry)
    })
  ,
  'DESCRIPTOR' : _UPDATEFEATUREREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.offlinefeaturestored.v1.offlinefeaturestored_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.offlinefeaturestored.v1.UpdateFeatureRequest)
  })
_sym_db.RegisterMessage(UpdateFeatureRequest)
_sym_db.RegisterMessage(UpdateFeatureRequest.SecretEntry)

UpdateFeatureResponse = _reflection.GeneratedProtocolMessageType('UpdateFeatureResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEFEATURERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.offlinefeaturestored.v1.offlinefeaturestored_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.offlinefeaturestored.v1.UpdateFeatureResponse)
  })
_sym_db.RegisterMessage(UpdateFeatureResponse)

ListFeaturesRequest = _reflection.GeneratedProtocolMessageType('ListFeaturesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LISTFEATURESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.offlinefeaturestored.v1.offlinefeaturestored_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.offlinefeaturestored.v1.ListFeaturesRequest)
  })
_sym_db.RegisterMessage(ListFeaturesRequest)

ListFeaturesResponse = _reflection.GeneratedProtocolMessageType('ListFeaturesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTFEATURESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.offlinefeaturestored.v1.offlinefeaturestored_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.offlinefeaturestored.v1.ListFeaturesResponse)
  })
_sym_db.RegisterMessage(ListFeaturesResponse)

GetFeatureRequest = _reflection.GeneratedProtocolMessageType('GetFeatureRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATUREREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.offlinefeaturestored.v1.offlinefeaturestored_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.offlinefeaturestored.v1.GetFeatureRequest)
  })
_sym_db.RegisterMessage(GetFeatureRequest)

GetFeatureResponse = _reflection.GeneratedProtocolMessageType('GetFeatureResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETFEATURERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.offlinefeaturestored.v1.offlinefeaturestored_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.offlinefeaturestored.v1.GetFeatureResponse)
  })
_sym_db.RegisterMessage(GetFeatureResponse)

GenerateTrainingDatasetRequest = _reflection.GeneratedProtocolMessageType('GenerateTrainingDatasetRequest', (_message.Message,), {
  'DESCRIPTOR' : _GENERATETRAININGDATASETREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.offlinefeaturestored.v1.offlinefeaturestored_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.offlinefeaturestored.v1.GenerateTrainingDatasetRequest)
  })
_sym_db.RegisterMessage(GenerateTrainingDatasetRequest)

GenerateTrainingDatasetResponse = _reflection.GeneratedProtocolMessageType('GenerateTrainingDatasetResponse', (_message.Message,), {
  'DESCRIPTOR' : _GENERATETRAININGDATASETRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.offlinefeaturestored.v1.offlinefeaturestored_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.offlinefeaturestored.v1.GenerateTrainingDatasetResponse)
  })
_sym_db.RegisterMessage(GenerateTrainingDatasetResponse)

_OFFLINEFEATURESTORESERVICE = DESCRIPTOR.services_by_name['OfflineFeatureStoreService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z>github.com/metaprov/modelaapi/services/offlinefeaturestored/v1'
  _CREATEFEATUREREQUEST_SECRETENTRY._options = None
  _CREATEFEATUREREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _UPDATEFEATUREREQUEST_SECRETENTRY._options = None
  _UPDATEFEATUREREQUEST_SECRETENTRY._serialized_options = b'8\001'
  _CREATEFEATUREREQUEST._serialized_start=299
  _CREATEFEATUREREQUEST._serialized_end=649
  _CREATEFEATUREREQUEST_SECRETENTRY._serialized_start=604
  _CREATEFEATUREREQUEST_SECRETENTRY._serialized_end=649
  _CREATEFEATURERESPONSE._serialized_start=651
  _CREATEFEATURERESPONSE._serialized_end=674
  _DELETEFEATUREREQUEST._serialized_start=676
  _DELETEFEATUREREQUEST._serialized_end=724
  _DELETEFEATURERESPONSE._serialized_start=726
  _DELETEFEATURERESPONSE._serialized_end=749
  _UPDATEFEATUREREQUEST._serialized_start=752
  _UPDATEFEATUREREQUEST._serialized_end=1102
  _UPDATEFEATUREREQUEST_SECRETENTRY._serialized_start=604
  _UPDATEFEATUREREQUEST_SECRETENTRY._serialized_end=649
  _UPDATEFEATURERESPONSE._serialized_start=1104
  _UPDATEFEATURERESPONSE._serialized_end=1127
  _LISTFEATURESREQUEST._serialized_start=1129
  _LISTFEATURESREQUEST._serialized_end=1162
  _LISTFEATURESRESPONSE._serialized_start=1164
  _LISTFEATURESRESPONSE._serialized_end=1271
  _GETFEATUREREQUEST._serialized_start=1273
  _GETFEATUREREQUEST._serialized_end=1318
  _GETFEATURERESPONSE._serialized_start=1320
  _GETFEATURERESPONSE._serialized_end=1420
  _GENERATETRAININGDATASETREQUEST._serialized_start=1423
  _GENERATETRAININGDATASETREQUEST._serialized_end=1566
  _GENERATETRAININGDATASETRESPONSE._serialized_start=1568
  _GENERATETRAININGDATASETRESPONSE._serialized_end=1601
  _OFFLINEFEATURESTORESERVICE._serialized_start=1604
  _OFFLINEFEATURESTORESERVICE._serialized_end=2808
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from github.com.metaprov.modelaapi.services.batchpredictord.v1 import batchpredictord_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_batchpredictord_dot_v1_dot_batchpredictord__pb2


class BatchStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.BatchPredict = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.batchpredictord.v1.Batch/BatchPredict',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_batchpredictord_dot_v1_dot_batchpredictord__pb2.BatchPredictRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_batchpredictord_dot_v1_dot_batchpredictord__pb2.BatchPredictResponse.FromString,
                )
        self.Shutdown = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.batchpredictord.v1.Batch/Shutdown',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_batchpredictord_dot_v1_dot_batchpredictord__pb2.ShutdownRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_batchpredictord_dot_v1_dot_batchpredictord__pb2.ShutdownResponse.FromString,
                )


class BatchServicer(object):
    """Missing associated documentation comment in .proto file."""

    def BatchPredict(self, request, context):
        """Ingest a new dataset to the store, the store creates a new layouts and set of keys
        for the new dataset
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Shutdown(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_BatchServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'BatchPredict': grpc.unary_unary_rpc_method_handler(
                    servicer.BatchPredict,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_batchpredictord_dot_v1_dot_batchpredictord__pb2.BatchPredictRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_batchpredictord_dot_v1_dot_batchpredictord__pb2.BatchPredictResponse.SerializeToString,
            ),
            'Shutdown': grpc.unary_unary_rpc_method_handler(
                    servicer.Shutdown,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_batchpredictord_dot_v1_dot_batchpredictord__pb2.ShutdownRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_batchpredictord_dot_v1_dot_batchpredictord__pb2.ShutdownResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'github.com.metaprov.modelaapi.services.batchpredictord.v1.Batch', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Batch(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def BatchPredict(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.batchpredictord.v1.Batch/BatchPredict',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_batchpredictord_dot_v1_dot_batchpredictord__pb2.BatchPredictRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_batchpredictord_dot_v1_dot_batchpredictord__pb2.BatchPredictResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Shutdown(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.batchpredictord.v1.Batch/Shutdown',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_batchpredictord_dot_v1_dot_batchpredictord__pb2.ShutdownRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_batchpredictord_dot_v1_dot_batchpredictord__pb2.ShutdownResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from github.com.metaprov.modelaapi.services.notifier.v1 import notifier_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notifier_dot_v1_dot_notifier__pb2


class NotifierServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListNotifiers = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.notifier.v1.NotifierService/ListNotifiers',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notifier_dot_v1_dot_notifier__pb2.ListNotifiersRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notifier_dot_v1_dot_notifier__pb2.ListNotifiersResponse.FromString,
                )
        self.CreateNotifier = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.notifier.v1.NotifierService/CreateNotifier',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notifier_dot_v1_dot_notifier__pb2.CreateNotifierRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notifier_dot_v1_dot_notifier__pb2.CreateNotifierResponse.FromString,
                )
        self.GetNotifier = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.notifier.v1.NotifierService/GetNotifier',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notifier_dot_v1_dot_notifier__pb2.GetNotifierRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notifier_dot_v1_dot_notifier__pb2.GetNotifierResponse.FromString,
                )
        self.UpdateNotifier = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.notifier.v1.NotifierService/UpdateNotifier',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notifier_dot_v1_dot_notifier__pb2.UpdateNotifierRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notifier_dot_v1_dot_notifier__pb2.UpdateNotifierResponse.FromString,
                )
        self.DeleteNotifier = channel.unary_unary(
                '/github.com.metaprov.modelaapi.services.notifier.v1.NotifierService/DeleteNotifier',
                request_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notifier_dot_v1_dot_notifier__pb2.DeleteNotifierRequest.SerializeToString,
                response_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notifier_dot_v1_dot_notifier__pb2.DeleteNotifierResponse.FromString,
                )


class NotifierServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListNotifiers(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def CreateNotifier(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetNotifier(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateNotifier(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteNotifier(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_NotifierServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListNotifiers': grpc.unary_unary_rpc_method_handler(
                    servicer.ListNotifiers,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notifier_dot_v1_dot_notifier__pb2.ListNotifiersRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notifier_dot_v1_dot_notifier__pb2.ListNotifiersResponse.SerializeToString,
            ),
            'CreateNotifier': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateNotifier,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notifier_dot_v1_dot_notifier__pb2.CreateNotifierRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notifier_dot_v1_dot_notifier__pb2.CreateNotifierResponse.SerializeToString,
            ),
            'GetNotifier': grpc.unary_unary_rpc_method_handler(
                    servicer.GetNotifier,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notifier_dot_v1_dot_notifier__pb2.GetNotifierRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notifier_dot_v1_dot_notifier__pb2.GetNotifierResponse.SerializeToString,
            ),
            'UpdateNotifier': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateNotifier,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notifier_dot_v1_dot_notifier__pb2.UpdateNotifierRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notifier_dot_v1_dot_notifier__pb2.UpdateNotifierResponse.SerializeToString,
            ),
            'DeleteNotifier': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteNotifier,
                    request_deserializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notifier_dot_v1_dot_notifier__pb2.DeleteNotifierRequest.FromString,
                    response_serializer=github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notifier_dot_v1_dot_notifier__pb2.DeleteNotifierResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'github.com.metaprov.modelaapi.services.notifier.v1.NotifierService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class NotifierService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListNotifiers(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.notifier.v1.NotifierService/ListNotifiers',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notifier_dot_v1_dot_notifier__pb2.ListNotifiersRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notifier_dot_v1_dot_notifier__pb2.ListNotifiersResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def CreateNotifier(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.notifier.v1.NotifierService/CreateNotifier',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notifier_dot_v1_dot_notifier__pb2.CreateNotifierRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notifier_dot_v1_dot_notifier__pb2.CreateNotifierResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetNotifier(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.notifier.v1.NotifierService/GetNotifier',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notifier_dot_v1_dot_notifier__pb2.GetNotifierRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notifier_dot_v1_dot_notifier__pb2.GetNotifierResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateNotifier(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.notifier.v1.NotifierService/UpdateNotifier',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notifier_dot_v1_dot_notifier__pb2.UpdateNotifierRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notifier_dot_v1_dot_notifier__pb2.UpdateNotifierResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteNotifier(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/github.com.metaprov.modelaapi.services.notifier.v1.NotifierService/DeleteNotifier',
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notifier_dot_v1_dot_notifier__pb2.DeleteNotifierRequest.SerializeToString,
            github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_notifier_dot_v1_dot_notifier__pb2.DeleteNotifierResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/system/v1/system.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='github.com/metaprov/modelaapi/services/system/v1/system.proto',
  package='github.com.metaprov.modelaapi.services.servingsite.v1',
  syntax='proto3',
  serialized_options=b'Z5github.com/metaprov/modelaapi/services/servingsite/v1',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n=github.com/metaprov/modelaapi/services/system/v1/system.proto\x12\x35github.com.metaprov.modelaapi.services.servingsite.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x45github.com/metaprov/modelaapi/pkg/apis/infra/v1alpha1/generated.proto\"6\n\x16\x44ownloadLogFileRequest\x12\x0e\n\x06\x62ucket\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\")\n\x17\x44ownloadLogFileResponse\x12\x0e\n\x06result\x18\x01 \x01(\x0c\"5\n\x15\x42\x61\x63kupDatabaseRequest\x12\x0e\n\x06\x62ucket\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\"&\n\x16\x42\x61\x63kupDatabaseResponse\x12\x0c\n\x04path\x18\x01 \x01(\t\"1\n\x11\x42\x61\x63kupEtcdRequest\x12\x0e\n\x06\x62ucket\x18\x01 \x01(\t\x12\x0c\n\x04path\x18\x02 \x01(\t\"\"\n\x12\x42\x61\x63kupEtcdResponse\x12\x0c\n\x04path\x18\x01 \x01(\t2\xda\x04\n\rSystemService\x12\xc6\x01\n\x0f\x44ownloadLogfile\x12M.github.com.metaprov.modelaapi.services.servingsite.v1.DownloadLogFileRequest\x1aN.github.com.metaprov.modelaapi.services.servingsite.v1.DownloadLogFileResponse\"\x14\x82\xd3\xe4\x93\x02\x0e\x12\x0c/v1/download\x12\xc3\x01\n\x0e\x42\x61\x63kupDatabase\x12L.github.com.metaprov.modelaapi.services.servingsite.v1.BackupDatabaseRequest\x1aM.github.com.metaprov.modelaapi.services.servingsite.v1.BackupDatabaseResponse\"\x14\x82\xd3\xe4\x93\x02\x0e\"\x0c/v1/backupdb\x12\xb9\x01\n\nBackupEtcd\x12H.github.com.metaprov.modelaapi.services.servingsite.v1.BackupEtcdRequest\x1aI.github.com.metaprov.modelaapi.services.servingsite.v1.BackupEtcdResponse\"\x16\x82\xd3\xe4\x93\x02\x10\"\x0e/v1/backupetcdB7Z5github.com/metaprov/modelaapi/services/servingsite/v1b\x06proto3'
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2.DESCRIPTOR,])




_DOWNLOADLOGFILEREQUEST = _descriptor.Descriptor(
  name='DownloadLogFileRequest',
  full_name='github.com.metaprov.modelaapi.services.servingsite.v1.DownloadLogFileRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bucket', full_name='github.com.metaprov.modelaapi.services.servingsite.v1.DownloadLogFileRequest.bucket', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='github.com.metaprov.modelaapi.services.servingsite.v1.DownloadLogFileRequest.path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=221,
  serialized_end=275,
)


_DOWNLOADLOGFILERESPONSE = _descriptor.Descriptor(
  name='DownloadLogFileResponse',
  full_name='github.com.metaprov.modelaapi.services.servingsite.v1.DownloadLogFileResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='github.com.metaprov.modelaapi.services.servingsite.v1.DownloadLogFileResponse.result', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=277,
  serialized_end=318,
)


_BACKUPDATABASEREQUEST = _descriptor.Descriptor(
  name='BackupDatabaseRequest',
  full_name='github.com.metaprov.modelaapi.services.servingsite.v1.BackupDatabaseRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bucket', full_name='github.com.metaprov.modelaapi.services.servingsite.v1.BackupDatabaseRequest.bucket', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='github.com.metaprov.modelaapi.services.servingsite.v1.BackupDatabaseRequest.path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=320,
  serialized_end=373,
)


_BACKUPDATABASERESPONSE = _descriptor.Descriptor(
  name='BackupDatabaseResponse',
  full_name='github.com.metaprov.modelaapi.services.servingsite.v1.BackupDatabaseResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='github.com.metaprov.modelaapi.services.servingsite.v1.BackupDatabaseResponse.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=375,
  serialized_end=413,
)


_BACKUPETCDREQUEST = _descriptor.Descriptor(
  name='BackupEtcdRequest',
  full_name='github.com.metaprov.modelaapi.services.servingsite.v1.BackupEtcdRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='bucket', full_name='github.com.metaprov.modelaapi.services.servingsite.v1.BackupEtcdRequest.bucket', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='path', full_name='github.com.metaprov.modelaapi.services.servingsite.v1.BackupEtcdRequest.path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=415,
  serialized_end=464,
)


_BACKUPETCDRESPONSE = _descriptor.Descriptor(
  name='BackupEtcdResponse',
  full_name='github.com.metaprov.modelaapi.services.servingsite.v1.BackupEtcdResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='path', full_name='github.com.metaprov.modelaapi.services.servingsite.v1.BackupEtcdResponse.path', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=466,
  serialized_end=500,
)

DESCRIPTOR.message_types_by_name['DownloadLogFileRequest'] = _DOWNLOADLOGFILEREQUEST
DESCRIPTOR.message_types_by_name['DownloadLogFileResponse'] = _DOWNLOADLOGFILERESPONSE
DESCRIPTOR.message_types_by_name['BackupDatabaseRequest'] = _BACKUPDATABASEREQUEST
DESCRIPTOR.message_types_by_name['BackupDatabaseResponse'] = _BACKUPDATABASERESPONSE
DESCRIPTOR.message_types_by_name['BackupEtcdRequest'] = _BACKUPETCDREQUEST
DESCRIPTOR.message_types_by_name['BackupEtcdResponse'] = _BACKUPETCDRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DownloadLogFileRequest = _reflection.GeneratedProtocolMessageType('DownloadLogFileRequest', (_message.Message,), {
  'DESCRIPTOR' : _DOWNLOADLOGFILEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.system.v1.system_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.servingsite.v1.DownloadLogFileRequest)
  })
_sym_db.RegisterMessage(DownloadLogFileRequest)

DownloadLogFileResponse = _reflection.GeneratedProtocolMessageType('DownloadLogFileResponse', (_message.Message,), {
  'DESCRIPTOR' : _DOWNLOADLOGFILERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.system.v1.system_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.servingsite.v1.DownloadLogFileResponse)
  })
_sym_db.RegisterMessage(DownloadLogFileResponse)

BackupDatabaseRequest = _reflection.GeneratedProtocolMessageType('BackupDatabaseRequest', (_message.Message,), {
  'DESCRIPTOR' : _BACKUPDATABASEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.system.v1.system_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.servingsite.v1.BackupDatabaseRequest)
  })
_sym_db.RegisterMessage(BackupDatabaseRequest)

BackupDatabaseResponse = _reflection.GeneratedProtocolMessageType('BackupDatabaseResponse', (_message.Message,), {
  'DESCRIPTOR' : _BACKUPDATABASERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.system.v1.system_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.servingsite.v1.BackupDatabaseResponse)
  })
_sym_db.RegisterMessage(BackupDatabaseResponse)

BackupEtcdRequest = _reflection.GeneratedProtocolMessageType('BackupEtcdRequest', (_message.Message,), {
  'DESCRIPTOR' : _BACKUPETCDREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.system.v1.system_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.servingsite.v1.BackupEtcdRequest)
  })
_sym_db.RegisterMessage(BackupEtcdRequest)

BackupEtcdResponse = _reflection.GeneratedProtocolMessageType('BackupEtcdResponse', (_message.Message,), {
  'DESCRIPTOR' : _BACKUPETCDRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.system.v1.system_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.servingsite.v1.BackupEtcdResponse)
  })
_sym_db.RegisterMessage(BackupEtcdResponse)


DESCRIPTOR._options = None

_SYSTEMSERVICE = _descriptor.ServiceDescriptor(
  name='SystemService',
  full_name='github.com.metaprov.modelaapi.services.servingsite.v1.SystemService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=503,
  serialized_end=1105,
  methods=[
  _descriptor.MethodDescriptor(
    name='DownloadLogfile',
    full_name='github.com.metaprov.modelaapi.services.servingsite.v1.SystemService.DownloadLogfile',
    index=0,
    containing_service=None,
    input_type=_DOWNLOADLOGFILEREQUEST,
    output_type=_DOWNLOADLOGFILERESPONSE,
    serialized_options=b'\202\323\344\223\002\016\022\014/v1/download',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='BackupDatabase',
    full_name='github.com.metaprov.modelaapi.services.servingsite.v1.SystemService.BackupDatabase',
    index=1,
    containing_service=None,
    input_type=_BACKUPDATABASEREQUEST,
    output_type=_BACKUPDATABASERESPONSE,
    serialized_options=b'\202\323\344\223\002\016\"\014/v1/backupdb',
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='BackupEtcd',
    full_name='github.com.metaprov.modelaapi.services.servingsite.v1.SystemService.BackupEtcd',
    index=2,
    containing_service=None,
    input_type=_BACKUPETCDREQUEST,
    output_type=_BACKUPETCDRESPONSE,
    serialized_options=b'\202\323\344\223\002\020\"\016/v1/backupetcd',
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_SYSTEMSERVICE)

DESCRIPTOR.services_by_name['SystemService'] = _SYSTEMSERVICE

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/apitoken/v1/apitoken.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_infra_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.services.common.v1 import common_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAgithub.com/metaprov/modelaapi/services/apitoken/v1/apitoken.proto\x12\x32github.com.metaprov.modelaapi.services.apitoken.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x45github.com/metaprov/modelaapi/pkg/apis/infra/v1alpha1/generated.proto\x1a=github.com/metaprov/modelaapi/services/common/v1/common.proto\x1a google/protobuf/field_mask.proto\"\xf7\x01\n\x14ListApiTokensRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x64\n\x06labels\x18\x02 \x03(\x0b\x32T.github.com.metaprov.modelaapi.services.apitoken.v1.ListApiTokensRequest.LabelsEntry\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\x12\x10\n\x08order_by\x18\x05 \x01(\t\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x88\x01\n\x15ListApiTokensResponse\x12V\n\tapitokens\x18\x01 \x01(\x0b\x32\x43.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.ApiTokenList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x12\n\x10\x41piTokenResponse\"|\n\x15\x43reateApiTokenRequest\x12Q\n\x08\x61pitoken\x18\x01 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.ApiToken\x12\x10\n\x08password\x18\x02 \x01(\t\"\x18\n\x16\x43reateApiTokenResponse\"\x9b\x01\n\x15UpdateApiTokenRequest\x12Q\n\x08\x61pitoken\x18\x01 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.ApiToken\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\x18\n\x16UpdateApiTokenResponse\"5\n\x12GetApiTokenRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"v\n\x13GetApiTokenResponse\x12Q\n\x08\x61pitoken\x18\x01 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.infra.v1alpha1.ApiToken\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"?\n\x1cGetApiTokenNamespacesRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"t\n\x1dGetApiTokenNamespacesResponse\x12S\n\nnamespaces\x18\x01 \x03(\x0b\x32?.github.com.metaprov.modelaapi.services.common.v1.NamespaceInfo\"8\n\x15\x44\x65leteApiTokenRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x18\n\x16\x44\x65leteApiTokenResponse\"\x18\n\x16\x41piTokenCreateResponse\"I\n\x14\x41piTokenLoginRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08password\x18\x03 \x01(\t\"&\n\x15\x41piTokenLoginResponse\x12\r\n\x05token\x18\x01 \x01(\t2\xb9\x08\n\x0f\x41piTokenService\x12\xc7\x01\n\rListApiTokens\x12H.github.com.metaprov.modelaapi.services.apitoken.v1.ListApiTokensRequest\x1aI.github.com.metaprov.modelaapi.services.apitoken.v1.ListApiTokensResponse\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/v1/apitokens/{namespace}\x12\xc1\x01\n\x0e\x43reateApiToken\x12I.github.com.metaprov.modelaapi.services.apitoken.v1.CreateApiTokenRequest\x1aJ.github.com.metaprov.modelaapi.services.apitoken.v1.CreateApiTokenResponse\"\x18\x82\xd3\xe4\x93\x02\x12\"\r/v1/apitokens:\x01*\x12\xc8\x01\n\x0bGetApiToken\x12\x46.github.com.metaprov.modelaapi.services.apitoken.v1.GetApiTokenRequest\x1aG.github.com.metaprov.modelaapi.services.apitoken.v1.GetApiTokenResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /v1/apitokens/{namespace}/{name}\x12\xf8\x01\n\x0eUpdateApiToken\x12I.github.com.metaprov.modelaapi.services.apitoken.v1.UpdateApiTokenRequest\x1aJ.github.com.metaprov.modelaapi.services.apitoken.v1.UpdateApiTokenResponse\"O\x82\xd3\xe4\x93\x02I\x1a\x44/v1/apitokens/{apitoken.metadata.namespace}/{apitoken.metadata.name}:\x01*\x12\xd1\x01\n\x0e\x44\x65leteApiToken\x12I.github.com.metaprov.modelaapi.services.apitoken.v1.DeleteApiTokenRequest\x1aJ.github.com.metaprov.modelaapi.services.apitoken.v1.DeleteApiTokenResponse\"(\x82\xd3\xe4\x93\x02\"* /v1/apitokens/{namespace}/{name}B4Z2github.com/metaprov/modelaapi/services/apitoken/v1b\x06proto3')



_LISTAPITOKENSREQUEST = DESCRIPTOR.message_types_by_name['ListApiTokensRequest']
_LISTAPITOKENSREQUEST_LABELSENTRY = _LISTAPITOKENSREQUEST.nested_types_by_name['LabelsEntry']
_LISTAPITOKENSRESPONSE = DESCRIPTOR.message_types_by_name['ListApiTokensResponse']
_APITOKENRESPONSE = DESCRIPTOR.message_types_by_name['ApiTokenResponse']
_CREATEAPITOKENREQUEST = DESCRIPTOR.message_types_by_name['CreateApiTokenRequest']
_CREATEAPITOKENRESPONSE = DESCRIPTOR.message_types_by_name['CreateApiTokenResponse']
_UPDATEAPITOKENREQUEST = DESCRIPTOR.message_types_by_name['UpdateApiTokenRequest']
_UPDATEAPITOKENRESPONSE = DESCRIPTOR.message_types_by_name['UpdateApiTokenResponse']
_GETAPITOKENREQUEST = DESCRIPTOR.message_types_by_name['GetApiTokenRequest']
_GETAPITOKENRESPONSE = DESCRIPTOR.message_types_by_name['GetApiTokenResponse']
_GETAPITOKENNAMESPACESREQUEST = DESCRIPTOR.message_types_by_name['GetApiTokenNamespacesRequest']
_GETAPITOKENNAMESPACESRESPONSE = DESCRIPTOR.message_types_by_name['GetApiTokenNamespacesResponse']
_DELETEAPITOKENREQUEST = DESCRIPTOR.message_types_by_name['DeleteApiTokenRequest']
_DELETEAPITOKENRESPONSE = DESCRIPTOR.message_types_by_name['DeleteApiTokenResponse']
_APITOKENCREATERESPONSE = DESCRIPTOR.message_types_by_name['ApiTokenCreateResponse']
_APITOKENLOGINREQUEST = DESCRIPTOR.message_types_by_name['ApiTokenLoginRequest']
_APITOKENLOGINRESPONSE = DESCRIPTOR.message_types_by_name['ApiTokenLoginResponse']
ListApiTokensRequest = _reflection.GeneratedProtocolMessageType('ListApiTokensRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTAPITOKENSREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.ListApiTokensRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTAPITOKENSREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.ListApiTokensRequest)
  })
_sym_db.RegisterMessage(ListApiTokensRequest)
_sym_db.RegisterMessage(ListApiTokensRequest.LabelsEntry)

ListApiTokensResponse = _reflection.GeneratedProtocolMessageType('ListApiTokensResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTAPITOKENSRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.ListApiTokensResponse)
  })
_sym_db.RegisterMessage(ListApiTokensResponse)

ApiTokenResponse = _reflection.GeneratedProtocolMessageType('ApiTokenResponse', (_message.Message,), {
  'DESCRIPTOR' : _APITOKENRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.ApiTokenResponse)
  })
_sym_db.RegisterMessage(ApiTokenResponse)

CreateApiTokenRequest = _reflection.GeneratedProtocolMessageType('CreateApiTokenRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEAPITOKENREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.CreateApiTokenRequest)
  })
_sym_db.RegisterMessage(CreateApiTokenRequest)

CreateApiTokenResponse = _reflection.GeneratedProtocolMessageType('CreateApiTokenResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATEAPITOKENRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.CreateApiTokenResponse)
  })
_sym_db.RegisterMessage(CreateApiTokenResponse)

UpdateApiTokenRequest = _reflection.GeneratedProtocolMessageType('UpdateApiTokenRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEAPITOKENREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.UpdateApiTokenRequest)
  })
_sym_db.RegisterMessage(UpdateApiTokenRequest)

UpdateApiTokenResponse = _reflection.GeneratedProtocolMessageType('UpdateApiTokenResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEAPITOKENRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.UpdateApiTokenResponse)
  })
_sym_db.RegisterMessage(UpdateApiTokenResponse)

GetApiTokenRequest = _reflection.GeneratedProtocolMessageType('GetApiTokenRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETAPITOKENREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.GetApiTokenRequest)
  })
_sym_db.RegisterMessage(GetApiTokenRequest)

GetApiTokenResponse = _reflection.GeneratedProtocolMessageType('GetApiTokenResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETAPITOKENRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.GetApiTokenResponse)
  })
_sym_db.RegisterMessage(GetApiTokenResponse)

GetApiTokenNamespacesRequest = _reflection.GeneratedProtocolMessageType('GetApiTokenNamespacesRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETAPITOKENNAMESPACESREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.GetApiTokenNamespacesRequest)
  })
_sym_db.RegisterMessage(GetApiTokenNamespacesRequest)

GetApiTokenNamespacesResponse = _reflection.GeneratedProtocolMessageType('GetApiTokenNamespacesResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETAPITOKENNAMESPACESRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.GetApiTokenNamespacesResponse)
  })
_sym_db.RegisterMessage(GetApiTokenNamespacesResponse)

DeleteApiTokenRequest = _reflection.GeneratedProtocolMessageType('DeleteApiTokenRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETEAPITOKENREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.DeleteApiTokenRequest)
  })
_sym_db.RegisterMessage(DeleteApiTokenRequest)

DeleteApiTokenResponse = _reflection.GeneratedProtocolMessageType('DeleteApiTokenResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETEAPITOKENRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.DeleteApiTokenResponse)
  })
_sym_db.RegisterMessage(DeleteApiTokenResponse)

ApiTokenCreateResponse = _reflection.GeneratedProtocolMessageType('ApiTokenCreateResponse', (_message.Message,), {
  'DESCRIPTOR' : _APITOKENCREATERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.ApiTokenCreateResponse)
  })
_sym_db.RegisterMessage(ApiTokenCreateResponse)

ApiTokenLoginRequest = _reflection.GeneratedProtocolMessageType('ApiTokenLoginRequest', (_message.Message,), {
  'DESCRIPTOR' : _APITOKENLOGINREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.ApiTokenLoginRequest)
  })
_sym_db.RegisterMessage(ApiTokenLoginRequest)

ApiTokenLoginResponse = _reflection.GeneratedProtocolMessageType('ApiTokenLoginResponse', (_message.Message,), {
  'DESCRIPTOR' : _APITOKENLOGINRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.apitoken.v1.apitoken_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.apitoken.v1.ApiTokenLoginResponse)
  })
_sym_db.RegisterMessage(ApiTokenLoginResponse)

_APITOKENSERVICE = DESCRIPTOR.services_by_name['ApiTokenService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z2github.com/metaprov/modelaapi/services/apitoken/v1'
  _LISTAPITOKENSREQUEST_LABELSENTRY._options = None
  _LISTAPITOKENSREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _APITOKENSERVICE.methods_by_name['ListApiTokens']._options = None
  _APITOKENSERVICE.methods_by_name['ListApiTokens']._serialized_options = b'\202\323\344\223\002\033\022\031/v1/apitokens/{namespace}'
  _APITOKENSERVICE.methods_by_name['CreateApiToken']._options = None
  _APITOKENSERVICE.methods_by_name['CreateApiToken']._serialized_options = b'\202\323\344\223\002\022\"\r/v1/apitokens:\001*'
  _APITOKENSERVICE.methods_by_name['GetApiToken']._options = None
  _APITOKENSERVICE.methods_by_name['GetApiToken']._serialized_options = b'\202\323\344\223\002\"\022 /v1/apitokens/{namespace}/{name}'
  _APITOKENSERVICE.methods_by_name['UpdateApiToken']._options = None
  _APITOKENSERVICE.methods_by_name['UpdateApiToken']._serialized_options = b'\202\323\344\223\002I\032D/v1/apitokens/{apitoken.metadata.namespace}/{apitoken.metadata.name}:\001*'
  _APITOKENSERVICE.methods_by_name['DeleteApiToken']._options = None
  _APITOKENSERVICE.methods_by_name['DeleteApiToken']._serialized_options = b'\202\323\344\223\002\"* /v1/apitokens/{namespace}/{name}'
  _LISTAPITOKENSREQUEST._serialized_start=320
  _LISTAPITOKENSREQUEST._serialized_end=567
  _LISTAPITOKENSREQUEST_LABELSENTRY._serialized_start=522
  _LISTAPITOKENSREQUEST_LABELSENTRY._serialized_end=567
  _LISTAPITOKENSRESPONSE._serialized_start=570
  _LISTAPITOKENSRESPONSE._serialized_end=706
  _APITOKENRESPONSE._serialized_start=708
  _APITOKENRESPONSE._serialized_end=726
  _CREATEAPITOKENREQUEST._serialized_start=728
  _CREATEAPITOKENREQUEST._serialized_end=852
  _CREATEAPITOKENRESPONSE._serialized_start=854
  _CREATEAPITOKENRESPONSE._serialized_end=878
  _UPDATEAPITOKENREQUEST._serialized_start=881
  _UPDATEAPITOKENREQUEST._serialized_end=1036
  _UPDATEAPITOKENRESPONSE._serialized_start=1038
  _UPDATEAPITOKENRESPONSE._serialized_end=1062
  _GETAPITOKENREQUEST._serialized_start=1064
  _GETAPITOKENREQUEST._serialized_end=1117
  _GETAPITOKENRESPONSE._serialized_start=1119
  _GETAPITOKENRESPONSE._serialized_end=1237
  _GETAPITOKENNAMESPACESREQUEST._serialized_start=1239
  _GETAPITOKENNAMESPACESREQUEST._serialized_end=1302
  _GETAPITOKENNAMESPACESRESPONSE._serialized_start=1304
  _GETAPITOKENNAMESPACESRESPONSE._serialized_end=1420
  _DELETEAPITOKENREQUEST._serialized_start=1422
  _DELETEAPITOKENREQUEST._serialized_end=1478
  _DELETEAPITOKENRESPONSE._serialized_start=1480
  _DELETEAPITOKENRESPONSE._serialized_end=1504
  _APITOKENCREATERESPONSE._serialized_start=1506
  _APITOKENCREATERESPONSE._serialized_end=1530
  _APITOKENLOGINREQUEST._serialized_start=1532
  _APITOKENLOGINREQUEST._serialized_end=1605
  _APITOKENLOGINRESPONSE._serialized_start=1607
  _APITOKENLOGINRESPONSE._serialized_end=1645
  _APITOKENSERVICE._serialized_start=1648
  _APITOKENSERVICE._serialized_end=2729
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: github.com/metaprov/modelaapi/services/study/v1/study.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1 import generated_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_pkg_dot_apis_dot_training_dot_v1alpha1_dot_generated__pb2
from github.com.metaprov.modelaapi.services.common.v1 import common_pb2 as github_dot_com_dot_metaprov_dot_modelaapi_dot_services_dot_common_dot_v1_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n;github.com/metaprov/modelaapi/services/study/v1/study.proto\x12/github.com.metaprov.modelaapi.services.study.v1\x1a google/protobuf/field_mask.proto\x1a\x1cgoogle/api/annotations.proto\x1aHgithub.com/metaprov/modelaapi/pkg/apis/training/v1alpha1/generated.proto\x1a=github.com/metaprov/modelaapi/services/common/v1/common.proto\"2\n\x0fGetStudyRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"p\n\x10GetStudyResponse\x12N\n\x05study\x18\x01 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\x12\x0c\n\x04yaml\x18\x02 \x01(\t\"\xb3\x01\n\x10ListStudyRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12]\n\x06labels\x18\x03 \x03(\x0b\x32M.github.com.metaprov.modelaapi.services.study.v1.ListStudyRequest.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x82\x01\n\x11ListStudyResponse\x12T\n\x07studies\x18\x01 \x01(\x0b\x32\x43.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.StudyList\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"d\n\x12\x43reateStudyRequest\x12N\n\x05study\x18\x01 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\"\x15\n\x13\x43reateStudyResponse\"\x94\x01\n\x12UpdateStudyRequest\x12N\n\x05study\x18\x01 \x01(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Study\x12.\n\nfield_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask\"\x8d\x01\n\x19\x43reateStudyProfileRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12O\n\x06models\x18\x03 \x03(\x0b\x32?.github.com.metaprov.modelaapi.pkg.apis.training.v1alpha1.Model\"J\n\x1a\x43reateStudyProfileResponse\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\"I\n\x16GetStudyProfileRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0e\n\x06models\x18\x03 \x01(\x05\"\xc1\x01\n\x17GetStudyProfileResponse\x12O\n\x07profile\x18\x01 \x01(\x0b\x32>.github.com.metaprov.modelaapi.services.common.v1.StudyProfile\x12U\n\rmodelsProfile\x18\x02 \x03(\x0b\x32>.github.com.metaprov.modelaapi.services.common.v1.ModelProfile\"4\n\x11\x41\x62ortStudyRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x14\n\x12\x41\x62ortStudyResponse\"4\n\x11PauseStudyRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x14\n\x12PauseStudyResponse\"5\n\x12ResumeStudyRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x15\n\x13ResumeStudyResponse\"5\n\x12\x44\x65leteStudyRequest\x12\x11\n\tnamespace\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"\x15\n\x13\x44\x65leteStudyResponse\"\x15\n\x13UpdateStudyResponse2\xe7\x0f\n\x0cStudyService\x12\xb5\x01\n\x0bListStudies\x12\x41.github.com.metaprov.modelaapi.services.study.v1.ListStudyRequest\x1a\x42.github.com.metaprov.modelaapi.services.study.v1.ListStudyResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/v1/studies/{namespace}\x12\xb0\x01\n\x0b\x43reateStudy\x12\x43.github.com.metaprov.modelaapi.services.study.v1.CreateStudyRequest\x1a\x44.github.com.metaprov.modelaapi.services.study.v1.CreateStudyResponse\"\x16\x82\xd3\xe4\x93\x02\x10\"\x0b/v1/studies:\x01*\x12\xb7\x01\n\x08GetStudy\x12@.github.com.metaprov.modelaapi.services.study.v1.GetStudyRequest\x1a\x41.github.com.metaprov.modelaapi.services.study.v1.GetStudyResponse\"&\x82\xd3\xe4\x93\x02 \x12\x1e/v1/studies/{namespace}/{name}\x12\xe1\x01\n\x0bUpdateStudy\x12\x43.github.com.metaprov.modelaapi.services.study.v1.UpdateStudyRequest\x1a\x44.github.com.metaprov.modelaapi.services.study.v1.UpdateStudyResponse\"G\x82\xd3\xe4\x93\x02\x41\x1a</v1/studies/{study.metadata.namespace}/{study.metadata.name}:\x01*\x12\xc0\x01\n\x0b\x44\x65leteStudy\x12\x43.github.com.metaprov.modelaapi.services.study.v1.DeleteStudyRequest\x1a\x44.github.com.metaprov.modelaapi.services.study.v1.DeleteStudyResponse\"&\x82\xd3\xe4\x93\x02 *\x1e/v1/studies/{namespace}/{name}\x12\xdd\x01\n\x12\x43reateStudyProfile\x12J.github.com.metaprov.modelaapi.services.study.v1.CreateStudyProfileRequest\x1aK.github.com.metaprov.modelaapi.services.study.v1.CreateStudyProfileResponse\".\x82\xd3\xe4\x93\x02(\"&/v1/studies/{namespace}/{name}/profile\x12\xd4\x01\n\x0fGetStudyProfile\x12G.github.com.metaprov.modelaapi.services.study.v1.GetStudyProfileRequest\x1aH.github.com.metaprov.modelaapi.services.study.v1.GetStudyProfileResponse\".\x82\xd3\xe4\x93\x02(\x12&/v1/studies/{namespace}/{name}/profile\x12\xc3\x01\n\nAbortStudy\x12\x42.github.com.metaprov.modelaapi.services.study.v1.AbortStudyRequest\x1a\x43.github.com.metaprov.modelaapi.services.study.v1.AbortStudyResponse\",\x82\xd3\xe4\x93\x02&\"$/v1/studies/{namespace}/{name}:abort\x12\xc3\x01\n\nPauseStudy\x12\x42.github.com.metaprov.modelaapi.services.study.v1.PauseStudyRequest\x1a\x43.github.com.metaprov.modelaapi.services.study.v1.PauseStudyResponse\",\x82\xd3\xe4\x93\x02&\"$/v1/studies/{namespace}/{name}:pause\x12\xc7\x01\n\x0bResumeStudy\x12\x43.github.com.metaprov.modelaapi.services.study.v1.ResumeStudyRequest\x1a\x44.github.com.metaprov.modelaapi.services.study.v1.ResumeStudyResponse\"-\x82\xd3\xe4\x93\x02\'\"%/v1/studies/{namespace}/{name}:resumeB1Z/github.com/metaprov/modelaapi/services/study/v1b\x06proto3')



_GETSTUDYREQUEST = DESCRIPTOR.message_types_by_name['GetStudyRequest']
_GETSTUDYRESPONSE = DESCRIPTOR.message_types_by_name['GetStudyResponse']
_LISTSTUDYREQUEST = DESCRIPTOR.message_types_by_name['ListStudyRequest']
_LISTSTUDYREQUEST_LABELSENTRY = _LISTSTUDYREQUEST.nested_types_by_name['LabelsEntry']
_LISTSTUDYRESPONSE = DESCRIPTOR.message_types_by_name['ListStudyResponse']
_CREATESTUDYREQUEST = DESCRIPTOR.message_types_by_name['CreateStudyRequest']
_CREATESTUDYRESPONSE = DESCRIPTOR.message_types_by_name['CreateStudyResponse']
_UPDATESTUDYREQUEST = DESCRIPTOR.message_types_by_name['UpdateStudyRequest']
_CREATESTUDYPROFILEREQUEST = DESCRIPTOR.message_types_by_name['CreateStudyProfileRequest']
_CREATESTUDYPROFILERESPONSE = DESCRIPTOR.message_types_by_name['CreateStudyProfileResponse']
_GETSTUDYPROFILEREQUEST = DESCRIPTOR.message_types_by_name['GetStudyProfileRequest']
_GETSTUDYPROFILERESPONSE = DESCRIPTOR.message_types_by_name['GetStudyProfileResponse']
_ABORTSTUDYREQUEST = DESCRIPTOR.message_types_by_name['AbortStudyRequest']
_ABORTSTUDYRESPONSE = DESCRIPTOR.message_types_by_name['AbortStudyResponse']
_PAUSESTUDYREQUEST = DESCRIPTOR.message_types_by_name['PauseStudyRequest']
_PAUSESTUDYRESPONSE = DESCRIPTOR.message_types_by_name['PauseStudyResponse']
_RESUMESTUDYREQUEST = DESCRIPTOR.message_types_by_name['ResumeStudyRequest']
_RESUMESTUDYRESPONSE = DESCRIPTOR.message_types_by_name['ResumeStudyResponse']
_DELETESTUDYREQUEST = DESCRIPTOR.message_types_by_name['DeleteStudyRequest']
_DELETESTUDYRESPONSE = DESCRIPTOR.message_types_by_name['DeleteStudyResponse']
_UPDATESTUDYRESPONSE = DESCRIPTOR.message_types_by_name['UpdateStudyResponse']
GetStudyRequest = _reflection.GeneratedProtocolMessageType('GetStudyRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSTUDYREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.study.v1.study_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.study.v1.GetStudyRequest)
  })
_sym_db.RegisterMessage(GetStudyRequest)

GetStudyResponse = _reflection.GeneratedProtocolMessageType('GetStudyResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETSTUDYRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.study.v1.study_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.study.v1.GetStudyResponse)
  })
_sym_db.RegisterMessage(GetStudyResponse)

ListStudyRequest = _reflection.GeneratedProtocolMessageType('ListStudyRequest', (_message.Message,), {

  'LabelsEntry' : _reflection.GeneratedProtocolMessageType('LabelsEntry', (_message.Message,), {
    'DESCRIPTOR' : _LISTSTUDYREQUEST_LABELSENTRY,
    '__module__' : 'github.com.metaprov.modelaapi.services.study.v1.study_pb2'
    # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.study.v1.ListStudyRequest.LabelsEntry)
    })
  ,
  'DESCRIPTOR' : _LISTSTUDYREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.study.v1.study_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.study.v1.ListStudyRequest)
  })
_sym_db.RegisterMessage(ListStudyRequest)
_sym_db.RegisterMessage(ListStudyRequest.LabelsEntry)

ListStudyResponse = _reflection.GeneratedProtocolMessageType('ListStudyResponse', (_message.Message,), {
  'DESCRIPTOR' : _LISTSTUDYRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.study.v1.study_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.study.v1.ListStudyResponse)
  })
_sym_db.RegisterMessage(ListStudyResponse)

CreateStudyRequest = _reflection.GeneratedProtocolMessageType('CreateStudyRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATESTUDYREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.study.v1.study_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.study.v1.CreateStudyRequest)
  })
_sym_db.RegisterMessage(CreateStudyRequest)

CreateStudyResponse = _reflection.GeneratedProtocolMessageType('CreateStudyResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATESTUDYRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.study.v1.study_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.study.v1.CreateStudyResponse)
  })
_sym_db.RegisterMessage(CreateStudyResponse)

UpdateStudyRequest = _reflection.GeneratedProtocolMessageType('UpdateStudyRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESTUDYREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.study.v1.study_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.study.v1.UpdateStudyRequest)
  })
_sym_db.RegisterMessage(UpdateStudyRequest)

CreateStudyProfileRequest = _reflection.GeneratedProtocolMessageType('CreateStudyProfileRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATESTUDYPROFILEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.study.v1.study_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.study.v1.CreateStudyProfileRequest)
  })
_sym_db.RegisterMessage(CreateStudyProfileRequest)

CreateStudyProfileResponse = _reflection.GeneratedProtocolMessageType('CreateStudyProfileResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATESTUDYPROFILERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.study.v1.study_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.study.v1.CreateStudyProfileResponse)
  })
_sym_db.RegisterMessage(CreateStudyProfileResponse)

GetStudyProfileRequest = _reflection.GeneratedProtocolMessageType('GetStudyProfileRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSTUDYPROFILEREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.study.v1.study_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.study.v1.GetStudyProfileRequest)
  })
_sym_db.RegisterMessage(GetStudyProfileRequest)

GetStudyProfileResponse = _reflection.GeneratedProtocolMessageType('GetStudyProfileResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETSTUDYPROFILERESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.study.v1.study_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.study.v1.GetStudyProfileResponse)
  })
_sym_db.RegisterMessage(GetStudyProfileResponse)

AbortStudyRequest = _reflection.GeneratedProtocolMessageType('AbortStudyRequest', (_message.Message,), {
  'DESCRIPTOR' : _ABORTSTUDYREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.study.v1.study_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.study.v1.AbortStudyRequest)
  })
_sym_db.RegisterMessage(AbortStudyRequest)

AbortStudyResponse = _reflection.GeneratedProtocolMessageType('AbortStudyResponse', (_message.Message,), {
  'DESCRIPTOR' : _ABORTSTUDYRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.study.v1.study_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.study.v1.AbortStudyResponse)
  })
_sym_db.RegisterMessage(AbortStudyResponse)

PauseStudyRequest = _reflection.GeneratedProtocolMessageType('PauseStudyRequest', (_message.Message,), {
  'DESCRIPTOR' : _PAUSESTUDYREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.study.v1.study_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.study.v1.PauseStudyRequest)
  })
_sym_db.RegisterMessage(PauseStudyRequest)

PauseStudyResponse = _reflection.GeneratedProtocolMessageType('PauseStudyResponse', (_message.Message,), {
  'DESCRIPTOR' : _PAUSESTUDYRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.study.v1.study_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.study.v1.PauseStudyResponse)
  })
_sym_db.RegisterMessage(PauseStudyResponse)

ResumeStudyRequest = _reflection.GeneratedProtocolMessageType('ResumeStudyRequest', (_message.Message,), {
  'DESCRIPTOR' : _RESUMESTUDYREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.study.v1.study_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.study.v1.ResumeStudyRequest)
  })
_sym_db.RegisterMessage(ResumeStudyRequest)

ResumeStudyResponse = _reflection.GeneratedProtocolMessageType('ResumeStudyResponse', (_message.Message,), {
  'DESCRIPTOR' : _RESUMESTUDYRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.study.v1.study_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.study.v1.ResumeStudyResponse)
  })
_sym_db.RegisterMessage(ResumeStudyResponse)

DeleteStudyRequest = _reflection.GeneratedProtocolMessageType('DeleteStudyRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETESTUDYREQUEST,
  '__module__' : 'github.com.metaprov.modelaapi.services.study.v1.study_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.study.v1.DeleteStudyRequest)
  })
_sym_db.RegisterMessage(DeleteStudyRequest)

DeleteStudyResponse = _reflection.GeneratedProtocolMessageType('DeleteStudyResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETESTUDYRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.study.v1.study_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.study.v1.DeleteStudyResponse)
  })
_sym_db.RegisterMessage(DeleteStudyResponse)

UpdateStudyResponse = _reflection.GeneratedProtocolMessageType('UpdateStudyResponse', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESTUDYRESPONSE,
  '__module__' : 'github.com.metaprov.modelaapi.services.study.v1.study_pb2'
  # @@protoc_insertion_point(class_scope:github.com.metaprov.modelaapi.services.study.v1.UpdateStudyResponse)
  })
_sym_db.RegisterMessage(UpdateStudyResponse)

_STUDYSERVICE = DESCRIPTOR.services_by_name['StudyService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z/github.com/metaprov/modelaapi/services/study/v1'
  _LISTSTUDYREQUEST_LABELSENTRY._options = None
  _LISTSTUDYREQUEST_LABELSENTRY._serialized_options = b'8\001'
  _STUDYSERVICE.methods_by_name['ListStudies']._options = None
  _STUDYSERVICE.methods_by_name['ListStudies']._serialized_options = b'\202\323\344\223\002\031\022\027/v1/studies/{namespace}'
  _STUDYSERVICE.methods_by_name['CreateStudy']._options = None
  _STUDYSERVICE.methods_by_name['CreateStudy']._serialized_options = b'\202\323\344\223\002\020\"\013/v1/studies:\001*'
  _STUDYSERVICE.methods_by_name['GetStudy']._options = None
  _STUDYSERVICE.methods_by_name['GetStudy']._serialized_options = b'\202\323\344\223\002 \022\036/v1/studies/{namespace}/{name}'
  _STUDYSERVICE.methods_by_name['UpdateStudy']._options = None
  _STUDYSERVICE.methods_by_name['UpdateStudy']._serialized_options = b'\202\323\344\223\002A\032</v1/studies/{study.metadata.namespace}/{study.metadata.name}:\001*'
  _STUDYSERVICE.methods_by_name['DeleteStudy']._options = None
  _STUDYSERVICE.methods_by_name['DeleteStudy']._serialized_options = b'\202\323\344\223\002 *\036/v1/studies/{namespace}/{name}'
  _STUDYSERVICE.methods_by_name['CreateStudyProfile']._options = None
  _STUDYSERVICE.methods_by_name['CreateStudyProfile']._serialized_options = b'\202\323\344\223\002(\"&/v1/studies/{namespace}/{name}/profile'
  _STUDYSERVICE.methods_by_name['GetStudyProfile']._options = None
  _STUDYSERVICE.methods_by_name['GetStudyProfile']._serialized_options = b'\202\323\344\223\002(\022&/v1/studies/{namespace}/{name}/profile'
  _STUDYSERVICE.methods_by_name['AbortStudy']._options = None
  _STUDYSERVICE.methods_by_name['AbortStudy']._serialized_options = b'\202\323\344\223\002&\"$/v1/studies/{namespace}/{name}:abort'
  _STUDYSERVICE.methods_by_name['PauseStudy']._options = None
  _STUDYSERVICE.methods_by_name['PauseStudy']._serialized_options = b'\202\323\344\223\002&\"$/v1/studies/{namespace}/{name}:pause'
  _STUDYSERVICE.methods_by_name['ResumeStudy']._options = None
  _STUDYSERVICE.methods_by_name['ResumeStudy']._serialized_options = b'\202\323\344\223\002\'\"%/v1/studies/{namespace}/{name}:resume'
  _GETSTUDYREQUEST._serialized_start=313
  _GETSTUDYREQUEST._serialized_end=363
  _GETSTUDYRESPONSE._serialized_start=365
  _GETSTUDYRESPONSE._serialized_end=477
  _LISTSTUDYREQUEST._serialized_start=480
  _LISTSTUDYREQUEST._serialized_end=659
  _LISTSTUDYREQUEST_LABELSENTRY._serialized_start=614
  _LISTSTUDYREQUEST_LABELSENTRY._serialized_end=659
  _LISTSTUDYRESPONSE._serialized_start=662
  _LISTSTUDYRESPONSE._serialized_end=792
  _CREATESTUDYREQUEST._serialized_start=794
  _CREATESTUDYREQUEST._serialized_end=894
  _CREATESTUDYRESPONSE._serialized_start=896
  _CREATESTUDYRESPONSE._serialized_end=917
  _UPDATESTUDYREQUEST._serialized_start=920
  _UPDATESTUDYREQUEST._serialized_end=1068
  _CREATESTUDYPROFILEREQUEST._serialized_start=1071
  _CREATESTUDYPROFILEREQUEST._serialized_end=1212
  _CREATESTUDYPROFILERESPONSE._serialized_start=1214
  _CREATESTUDYPROFILERESPONSE._serialized_end=1288
  _GETSTUDYPROFILEREQUEST._serialized_start=1290
  _GETSTUDYPROFILEREQUEST._serialized_end=1363
  _GETSTUDYPROFILERESPONSE._serialized_start=1366
  _GETSTUDYPROFILERESPONSE._serialized_end=1559
  _ABORTSTUDYREQUEST._serialized_start=1561
  _ABORTSTUDYREQUEST._serialized_end=1613
  _ABORTSTUDYRESPONSE._serialized_start=1615
  _ABORTSTUDYRESPONSE._serialized_end=1635
  _PAUSESTUDYREQUEST._serialized_start=1637
  _PAUSESTUDYREQUEST._serialized_end=1689
  _PAUSESTUDYRESPONSE._serialized_start=1691
  _PAUSESTUDYRESPONSE._serialized_end=1711
  _RESUMESTUDYREQUEST._serialized_start=1713
  _RESUMESTUDYREQUEST._serialized_end=1766
  _RESUMESTUDYRESPONSE._serialized_start=1768
  _RESUMESTUDYRESPONSE._serialized_end=1789
  _DELETESTUDYREQUEST._serialized_start=1791
  _DELETESTUDYREQUEST._serialized_end=1844
  _DELETESTUDYRESPONSE._serialized_start=1846
  _DELETESTUDYRESPONSE._serialized_end=1867
  _UPDATESTUDYRESPONSE._serialized_start=1869
  _UPDATESTUDYRESPONSE._serialized_end=1890
  _STUDYSERVICE._serialized_start=1893
  _STUDYSERVICE._serialized_end=3916
# @@protoc_insertion_point(module_scope)
